@@ -88,7 +88,8 @@ sub new
     'examples/*.so',
     'examples/*.dll',
     'examples/*.bundle',
-    'examples/rust/*.so',
+    'examples/java/*.so',
+    'examples/java/*.o',
     'xs/ffi_platypus_config.h',
     'config.log',
     'test*.o',
