@@ -6,7 +6,7 @@ use 5.008001;
 use Carp qw( croak );
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -462,7 +462,6 @@ sub package
   $self;
 }
 
-
 sub DESTROY
 {
   my($self) = @_;
@@ -476,7 +475,7 @@ sub DESTROY
 
 package FFI::Platypus::Function;
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 use overload '&{}' => sub {
   my $ffi = shift;
@@ -488,7 +487,7 @@ package FFI::Platypus::Closure;
 use Scalar::Util qw( refaddr);
 use Carp qw( croak );
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 our %cbdata;
 
@@ -515,13 +514,13 @@ sub DESTROY
 
 package FFI::Platypus::ClosureData;
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 sub new
 {
@@ -586,11 +585,11 @@ sub new
     $ffi_type = $type;
     $platypus_type = 'pointer';
   }
-  elsif($type =~ s/\s+\[([0-9]+)\]$//)
+  elsif($type =~ s/\s+\[([0-9]*)\]$//)
   {
     $ffi_type = $type;
     $platypus_type = 'array';
-    $size = $1;
+    $size = $1 ? $1 : 0;
   }
   else
   {
@@ -615,7 +614,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -633,8 +632,9 @@ version 0.21
 
 =head1 DESCRIPTION
 
-Platypus is an library for creating interfaces to machine code libraries 
-written in languages like C, L<C++|FFI::Platypus::Lang::CPP>, Fortran, 
+Platypus is a library for creating interfaces to machine code libraries 
+written in languages like C, L<C++|FFI::Platypus::Lang::CPP>, 
+L<Fortran|FFI::Platypus::Lang::Fortran>, 
 L<Rust|FFI::Platypus::Lang::Rust>, 
 L<Pascal|FFI::Platypus::Lang::Pascal>. Essentially anything that gets 
 compiled into machine code.  This implementation uses C<libffi> to 
@@ -686,9 +686,10 @@ XS is implemented primarily as a bunch of C macros, which requires at
 least some understanding of C, the C pre-processor, and some C++ caveats 
 (since on some platforms Perl is compiled and linked with a C++ 
 compiler). Platypus on the other hand could be used to call other 
-compiled languages, like Fortran, L<Rust|FFI::Platypus::Lang::Rust>, 
+compiled languages, like L<Fortran|FFI::Platypus::Lang::Fortran>, 
+L<Rust|FFI::Platypus::Lang::Rust>, 
 L<Pascal|FFI::Platypus::Lang::Pascal>, L<C++|FFI::Platypus::Lang::CPP>, 
-Go or even L<assembly|FFI::Platypus::Lang::ASM>, allowing you to focus 
+or even L<assembly|FFI::Platypus::Lang::ASM>, allowing you to focus 
 on your strengths.
 
 =item FFI / Platypus does not require a parser
@@ -1662,6 +1663,169 @@ will come in after that.  This allows you to modify / convert the
 arguments to conform to the C API.  What ever value you return from the 
 wrapper function will be returned back to the original caller.
 
+=head2 Java
+
+Java:
+
+ // On Linux build .so with
+ // % gcj -fPIC -shared -o libexample.so Example.java
+ 
+ public class Example
+ {
+   public static void print_hello()
+   {
+     System.out.println("hello world");
+   }
+ 
+   public static int add(int a, int b)
+   {
+     return a + b;
+   }
+ }
+
+C++:
+
+ #include <gcj/cni.h>
+ #include <java/lang/System.h>
+ #include <java/io/PrintStream.h>
+ #include <java/lang/Throwable.h>
+ 
+ extern "C" void
+ gcj_start()
+ {
+   using namespace java::lang;
+ 
+   JvCreateJavaVM(NULL);
+   JvInitClass(&System::class$);
+ }
+ 
+ extern "C" void
+ gcj_end()
+ {
+   JvDetachCurrentThread();
+ }
+
+Perl:
+
+ use FFI::Platypus;
+ 
+ my $ffi = FFI::Platypus->new;
+ $ffi->lib('./libexample.so');
+ 
+ # Java methods are mangled by gcj using the same format as g++
+ 
+ $ffi->attach(
+   [ _ZN7Example11print_helloEJvv => 'print_hello' ] => [] => 'void'
+ );
+ 
+ $ffi->attach(
+   [ _ZN7Example3addEJiii => 'add' ] => ['int', 'int'] => 'int'
+ );
+ 
+ # Initialize the Java runtime
+ 
+ $ffi->function( gcj_start => [] => 'void' )->call;
+ 
+ print_hello();
+ print add(1,2), "\n";
+ 
+ # Wind the java runtime down
+ 
+ $ffi->function( gcj_end => [] => 'void' )->call;
+
+Makefile:
+
+ GCJ=gcj
+ CXX=g++
+ CFLAGS=-fPIC
+ LDFLAGS=-shared
+ RM=rm -f
+ 
+ libexample.so: between.o Example.o
+ 	$(GCJ) $(LDFLAGS) -o libexample.so between.o Example.o
+ 
+ between.o: between.cpp
+ 	$(CXX) $(CFLAGS) -c -o between.o between.cpp
+ 
+ Example.o: Example.java
+ 	$(GCJ) $(CFLAGS) -c -o Example.o Example.java
+ 
+ clean:
+ 	$(RM) *.o *.so
+
+Output:
+
+ % make
+ g++ -fPIC -c -o between.o between.cpp
+ gcj -fPIC -c -o Example.o Example.java
+ gcj -shared -o libexample.so between.o Example.o
+ % perl example.pl 
+ hello world
+ 3
+
+B<Discussion>: You can't call Java .class files directly from FFI / 
+Platypus, but you can compile Java source and .class files into a shared 
+library using the GNU Java Compiler C<gcj>.  Because we are calling Java 
+functions from a program (Perl!) that was not started from a Java 
+C<main()> we have to initialize the Java runtime ourselves
+(L<details|https://gcc.gnu.org/onlinedocs/gcj/Invocation.html>).
+This can most easily be accomplished from C++.
+
+The GNU Java Compiler uses the same format to mangle method names as GNU 
+C++.  The L<C++ plugin|FFI::Platypus::Lang::CPP> for handles this more 
+transparently by extracting the symbols from the shared library and 
+using either L<FFI::Platypus::Lang::CPP::Demangle::XS> or C<c++filt> to 
+determined the unmangled names.
+
+Although the Java source is compiled ahead of time with optimizations, 
+it will not necessarily perform better than a real JVM just because it 
+is compiled.  In fact the gcj developers warn than gcj will optimize 
+Java source better than Java .class files.  The GNU Java Compiler also 
+lags behind modern Java.
+
+Even so this enables you to call Java from Perl and potentially other 
+Java based languages such as Scala, Groovy or JRuby.
+
+=head1 CAVEATS
+
+Platypus and Native Interfaces like libffi rely on the availability of 
+dynamic libraries.  Things not supported include:
+
+=over 4
+
+=item Systems that lack dynamic library support
+
+Like MS-DOS
+
+=item Systems that are not supported by libffi
+
+Like OpenVMS
+
+=item Languages that do not support using dynamic libraries from other languages
+
+Like Google's Go.  Although I believe that XS won't help in this 
+regard.
+
+=item Languages that do not compile to machine code
+
+Like .NET based languages and Java that can't be understood by gcj.
+
+=back
+
+The documentation has a bias toward using FFI / Platypus with C.  This 
+is my fault, as my background in mainly in C/C++ programmer (when I am 
+not writing Perl).  In many places I use "C" as a short form for "any 
+language that can generate machine code and is callable from C".  I 
+welcome pull requests to the Platypus core to address this issue.  In an 
+attempt to ease usage of Platypus by non C programmers, I have written a 
+number of foreign language plugins for various popular languages (see 
+the SEE ALSO below).  These plugins come with examples specific to those 
+languages, and documentation on common issues related to using those 
+languages with FFI.  In most cases these are available for easy adoption 
+for those with the know-how or the willingness to learn.  If your 
+language doesn't have a plugin YET, that is just because you haven't 
+written it yet.
+
 =head1 SUPPORT
 
 If something does not work the way you think it should, or if you have a 
@@ -1828,6 +1992,14 @@ language
 Documentation and tools for using Platypus with the C++ programming 
 language
 
+=item L<FFI::Platypus::Lang::Fortran>
+
+Documentation and tools for using Platypus with Fortran
+
+=item L<FFI::Platypus::Lang::Pascal>
+
+Documentation and tools for using Platypus with Free Pascal
+
 =item L<FFI::Platypus::Lang::Rust>
 
 Documentation and tools for using Platypus with the Rust programming 
@@ -1900,6 +2072,8 @@ Contributors:
 
 Bakkiaraj Murugesan (bakkiaraj)
 
+Zaki Mughal (zmughal)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Graham Ollis.
