@@ -9,7 +9,7 @@ use base qw( Exporter );
 our @EXPORT = qw( record_layout );
 
 # ABSTRACT: FFI support for structured records data
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 
 sub record_layout
@@ -135,7 +135,7 @@ FFI::Platypus::Record - FFI support for structured records data
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -217,8 +217,8 @@ class C<Foo>:
  use FFI::Platypus::Record;
  
  record_layout(
-   int          => 'bar',  #  In C: int baz;
-   'string(10)' => 'baz',  #  In C: char baz[10];
+   int          => 'bar',  #  int bar;
+   'string(10)' => 'baz',  #  char baz[10];
  );
 
 You can get and set its fields with like named C<bar> and C<baz> 
@@ -345,6 +345,8 @@ Contributors:
 
 Bakkiaraj Murugesan (bakkiaraj)
 
+Zaki Mughal (zmughal)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Graham Ollis.
